@@ -5,7 +5,7 @@ import sys
 logging.basicConfig(format="%(asctime)s %(levelname)s %(message)s",
                     level=logging.DEBUG,
                     stream=sys.stdout)
-import datetime
+import time
 import json
 # GUI
 from kivy.app import App
@@ -16,7 +16,7 @@ import hwrt.utils as utils
 
 
 def unix_time():
-    return int(datetime.datetime.now().strftime("%s"))
+    return lambda: int(round(time.time() * 1000))
 
 
 recording = []
