@@ -48,7 +48,7 @@ def get_class(name):
     return None
 
 
-def get_preprocessing_queue(model_description_preprocessing):
+def get_preprocessing_queue(preprocessing_list):
     """Get preprocessing queue from a list of dictionaries
 
     >>> l = [{'Remove_duplicate_time': None}, \
@@ -62,7 +62,7 @@ def get_preprocessing_queue(model_description_preprocessing):
     ]
     """
     preprocessing_queue = []
-    for preprocessing in model_description_preprocessing:
+    for preprocessing in preprocessing_list:
         for alg, params in preprocessing.items():
             alg = get_class(alg)
             if params is None:
